.. HiFive documentation master file, created by
   sphinx-quickstart on Thu Sep 18 16:53:06 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

HiFive's documentation
=======================

Contents:

.. toctree::
   :maxdepth: 2

   introduction.rst
   getting_started.rst
   fragment_handling.rst
   loading_data.rst
   filtering_data.rst
   distance_dependence.rst
   normalization.rst
   binning.rst
   mrheatmap.rst
   hifive.rst
   fivec_tutorial.rst
   hic_tutorial.rst
   api.rst
   release_history.rst

Indices and tables
++++++++++++++++++

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

